# asyncfix
![tests](https://github.com/alexveden/asyncfix/actions/workflows/build.yml/badge.svg)
![coverage](https://github.com/alexveden/asyncfix/blob/main/.github/coverage.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

AsyncIO FIX protocol library for Python
